@@ -1,10 +1,12 @@
 use super::{create_prompt_with_default, selected_rev, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, prompt::PromptData, state::State, term::Term, Res};
 use derive_more::Display;
-use std::{ffi::OsString, process::Command, rc::Rc};
+use std::{process::Command, rc::Rc};
 use tui_prompts::State as _;
 
-pub(crate) const ARGS: &[Arg] = &[];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![]
+}
 
 #[derive(Display)]
 #[display(fmt = "Checkout branch/revision")]
@@ -15,16 +17,18 @@ impl OpTrait for Checkout {
             "Checkout",
             checkout,
             selected_rev,
+            true,
         ))
     }
 }
 
-fn checkout(state: &mut State, term: &mut Term, args: &[OsString], rev: &str) -> Res<()> {
+fn checkout(state: &mut State, term: &mut Term, rev: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["checkout"]);
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(rev);
 
+    state.close_menu();
     state.run_cmd(term, &[], cmd)?;
     Ok(())
 }
@@ -35,6 +39,7 @@ pub(crate) struct CheckoutNewBranch;
 impl OpTrait for CheckoutNewBranch {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(Rc::new(|state: &mut State, _term: &mut Term| {
+            state.close_menu();
             state.prompt.set(PromptData {
                 prompt_text: "Create and checkout branch:".into(),
                 update_fn: Rc::new(checkout_new_branch_prompt_update),
@@ -51,6 +56,7 @@ fn checkout_new_branch_prompt_update(state: &mut State, term: &mut Term) -> Res<
 
         let mut cmd = Command::new("git");
         cmd.args(["checkout", "-b", &name]);
+
         state.run_cmd(term, &[], cmd)?;
     }
     Ok(())
