@@ -1,12 +1,14 @@
 use super::{create_prompt, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Res};
 use derive_more::Display;
-use std::{ffi::OsString, process::Command, rc::Rc};
+use std::{process::Command, rc::Rc};
 
-pub(crate) const ARGS: &[Arg] = &[
-    Arg::new("--prune", "Prune deleted branches", false),
-    Arg::new("--tags", "Fetch all tags", false),
-];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![
+        Arg::new_flag("--prune", "Prune deleted branches", false),
+        Arg::new_flag("--tags", "Fetch all tags", false),
+    ]
+}
 
 #[derive(Display)]
 #[display(fmt = "Fetch all")]
@@ -18,6 +20,7 @@ impl OpTrait for FetchAll {
             cmd.args(["fetch", "--all", "--jobs", "10"]);
             cmd.args(state.pending_menu.as_ref().unwrap().args());
 
+            state.close_menu();
             state.run_cmd_async(term, &[], cmd)?;
             Ok(())
         }))
@@ -29,16 +32,17 @@ impl OpTrait for FetchAll {
 pub(crate) struct FetchElsewhere;
 impl OpTrait for FetchElsewhere {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_prompt("Select remote", push_elsewhere))
+        Some(create_prompt("Select remote", push_elsewhere, true))
     }
 }
 
-fn push_elsewhere(state: &mut State, term: &mut Term, args: &[OsString], remote: &str) -> Res<()> {
+fn push_elsewhere(state: &mut State, term: &mut Term, remote: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["fetch"]);
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(remote);
 
+    state.close_menu();
     state.run_cmd_async(term, &[], cmd)?;
     Ok(())
 }
