@@ -1,14 +1,16 @@
 use super::{create_prompt, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Res};
 use derive_more::Display;
-use std::{ffi::OsString, process::Command, rc::Rc};
+use std::{process::Command, rc::Rc};
 
-pub(crate) const ARGS: &[Arg] = &[
-    Arg::new("--force-with-lease", "Force with lease", false),
-    Arg::new("--force", "Force", false),
-    Arg::new("--no-verify", "Disable hooks", false),
-    Arg::new("--dry-run", "Dry run", false),
-];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![
+        Arg::new_flag("--force-with-lease", "Force with lease", false),
+        Arg::new_flag("--force", "Force", false),
+        Arg::new_flag("--no-verify", "Disable hooks", false),
+        Arg::new_flag("--dry-run", "Dry run", false),
+    ]
+}
 
 #[derive(Display)]
 #[display(fmt = "Push")]
@@ -20,6 +22,7 @@ impl OpTrait for Push {
             cmd.args(["push"]);
             cmd.args(state.pending_menu.as_ref().unwrap().args());
 
+            state.close_menu();
             state.run_cmd_async(term, &[], cmd)?;
             Ok(())
         }))
@@ -31,16 +34,17 @@ impl OpTrait for Push {
 pub(crate) struct PushElsewhere;
 impl OpTrait for PushElsewhere {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_prompt("Select remote", push_elsewhere))
+        Some(create_prompt("Select remote", push_elsewhere, true))
     }
 }
 
-fn push_elsewhere(state: &mut State, term: &mut Term, args: &[OsString], remote: &str) -> Res<()> {
+fn push_elsewhere(state: &mut State, term: &mut Term, remote: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["push"]);
     cmd.arg(format!("--repo={}", remote));
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
 
+    state.close_menu();
     state.run_cmd_async(term, &[], cmd)?;
     Ok(())
 }
