@@ -1,9 +1,11 @@
 use super::{create_prompt_with_default, selected_rev, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Action, Res};
 use derive_more::Display;
-use std::{ffi::OsString, process::Command};
+use std::process::Command;
 
-pub(crate) const ARGS: &[Arg] = &[];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![]
+}
 
 #[derive(Display)]
 #[display(fmt = "Reset soft")]
@@ -14,15 +16,18 @@ impl OpTrait for ResetSoft {
             "Soft reset to",
             reset_soft,
             selected_rev,
+            true,
         ))
     }
 }
 
-fn reset_soft(state: &mut State, term: &mut Term, args: &[OsString], input: &str) -> Res<()> {
+fn reset_soft(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--soft"]);
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
+
+    state.close_menu();
     state.run_cmd(term, &[], cmd)
 }
 
@@ -35,15 +40,18 @@ impl OpTrait for ResetMixed {
             "Mixed reset to",
             reset_mixed,
             selected_rev,
+            true,
         ))
     }
 }
 
-fn reset_mixed(state: &mut State, term: &mut Term, args: &[OsString], input: &str) -> Res<()> {
+fn reset_mixed(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--mixed"]);
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
+
+    state.close_menu();
     state.run_cmd(term, &[], cmd)
 }
 
@@ -56,14 +64,17 @@ impl OpTrait for ResetHard {
             "Hard reset to",
             reset_hard,
             selected_rev,
+            true,
         ))
     }
 }
 
-fn reset_hard(state: &mut State, term: &mut Term, args: &[OsString], input: &str) -> Res<()> {
+fn reset_hard(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--hard"]);
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
+
+    state.close_menu();
     state.run_cmd(term, &[], cmd)
 }
